@@ -3,16 +3,17 @@
 
 import click
 
+from SoftLayer.CLI.command import SLCommand as SLCommand
 from SoftLayer.CLI import environment
 from SoftLayer.CLI import formatting
 from SoftLayer.managers.account import AccountManager as AccountManager
 from SoftLayer import utils
 
 
-@click.command()
+@click.command(cls=SLCommand)
 @click.option('--limit', '-l',
               help='How many results to get in one api call',
-              default=100,
+              default=50,
               show_default=True)
 @environment.pass_env
 def cli(env, limit):
