@@ -10,7 +10,6 @@ from SoftLayer.CLI import helpers
 
 COLUMNS = [
     'id',
-    'createDate',
     'networkIdentifier',
     'cidr'
 ]
@@ -33,7 +32,6 @@ def cli(env, access_id):
         table = formatting.Table(COLUMNS)
         for subnet in subnets:
             row = ["{0}".format(subnet['id']),
-                   "{0}".format(subnet['createDate']),
                    "{0}".format(subnet['networkIdentifier']),
                    "{0}".format(subnet['cidr'])]
             table.add_row(row)
