@@ -8,7 +8,7 @@ from SoftLayer.CLI import environment
 from SoftLayer import utils
 
 
-@click.command()
+@click.command(cls=SoftLayer.CLI.command.SLCommand, )
 @click.option('--date-min', '-d',
               help='The earliest date we want to search for event logs in mm/dd/yyyy format.')
 @click.option('--date-max', '-D',
@@ -47,7 +47,7 @@ def cli(env, date_min, date_max, obj_event, obj_id, obj_type, utc_offset, metada
     row_count = 0
     click.secho(", ".join(columns))
     for log in logs:
-        if log is None:
+        if isinstance(log, str) or log is None:
             click.secho('No logs available for filter %s.' % request_filter, fg='red')
             return
 
