@@ -12,7 +12,7 @@ class CLIHalt(SystemExit):
     """Smoothly halt the execution of the command. No error."""
 
     def __init__(self, code=0, *args):
-        super(CLIHalt, self).__init__(*args)
+        super().__init__(*args)
         self.code = code
 
     def __str__(self):
@@ -26,7 +26,7 @@ class CLIAbort(CLIHalt):
     """Halt the execution of the command. Gives an exit code of 2."""
 
     def __init__(self, msg, *args):
-        super(CLIAbort, self).__init__(code=2, *args)
+        super().__init__(code=2, *args)
         self.message = msg
 
 
@@ -34,5 +34,5 @@ class ArgumentError(CLIAbort):
     """Halt the execution of the command because of invalid arguments."""
 
     def __init__(self, msg, *args):
-        super(ArgumentError, self).__init__(msg, *args)
+        super().__init__(msg, *args)
         self.message = "Argument Error: %s" % msg
