@@ -2,13 +2,14 @@
 # :license: MIT, see LICENSE for more details.
 import click
 
+from SoftLayer.CLI.command import SLCommand as SLCommand
 from SoftLayer.CLI import environment
 from SoftLayer.CLI import formatting
 from SoftLayer.managers import ordering
 from SoftLayer.utils import lookup
 
 
-@click.command()
+@click.command(cls=SLCommand)
 @click.argument('quote')
 @environment.pass_env
 def cli(env, quote):
