@@ -7,7 +7,7 @@ import SoftLayer
 from SoftLayer.CLI import environment
 
 
-@click.command()
+@click.command(cls=SoftLayer.CLI.command.SLCommand, )
 @click.option('--crt',
               type=click.Path(exists=True),
               help="Certificate file")
@@ -28,16 +28,16 @@ def cli(env, crt, csr, icc, key, notes):
         'certificateSigningRequest': '',
         'notes': notes,
     }
-    with open(crt) as file_crt:
+    with open(crt, encoding="utf-8") as file_crt:
         template['certificate'] = file_crt.read()
-    with open(key) as file_key:
+    with open(key, encoding="utf-8") as file_key:
         template['privateKey'] = file_key.read()
-    with open(csr) as file_csr:
+    with open(csr, encoding="utf-8") as file_csr:
         if csr:
             body = file_csr.read()
             template['certificateSigningRequest'] = body
 
-    with open(icc) as file_icc:
+    with open(icc, encoding="utf-8") as file_icc:
         if icc:
             body = file_icc.read()
             template['intermediateCertificate'] = body
