@@ -8,7 +8,7 @@ from SoftLayer.CLI import environment
 from SoftLayer.CLI import helpers
 
 
-@click.command()
+@click.command(cls=SoftLayer.CLI.command.SLCommand, )
 @click.argument('identifier')
 @environment.pass_env
 def cli(env, identifier):
@@ -17,6 +17,7 @@ def cli(env, identifier):
     and will eventually be fully removed from the account by an automated internal process.
 
     Example: slcli user delete userId
+
     """
 
     mgr = SoftLayer.UserManager(env.client)
